@@ -202,7 +202,7 @@ print.metaLik <- function(x, digits = max(3, getOption("digits") - 3), ...)
 test.metaLik <- function(object, param=1, value=0, alternative=c("two.sided", "less", "greater"), print=TRUE){
 
   digits <- max(3, getOption("digits") - 3)
-  if(class(object)!="metaLik")
+  if(!inherits(object, "metaLik"))
     stop("\nfunction designed for 'metaLik' objects")
   beta.mle <- coef(object)
   if(is.character(param)){
@@ -218,7 +218,7 @@ test.metaLik <- function(object, param=1, value=0, alternative=c("two.sided", "l
   alternative <- match.arg(alternative)
   if(!missing(value) && (length(value)!= 1 || is.na(value)))
     stop("\n'value' must be a single number")
-  if(class(object)!="metaLik")
+  if(!inherits(object, "metaLik"))
     stop("\n'object' must be a metaLik object")
    
   pl <- .profLik(object, param=param)
@@ -283,7 +283,7 @@ residuals.metaLik <- function(object, type = c("pearson", "response", "working")
 summary.metaLik <- function(object, ...){
 
   digits <- max(3, getOption("digits") - 3)
-  if(class(object)!="metaLik")
+  if(!inherits(object, "metaLik"))
     stop("\n'summary.metaLik' designed for 'metaLik' objects\n")
   beta <- coef(object)
   nbeta <- length(beta)
@@ -312,7 +312,7 @@ summary.metaLik <- function(object, ...){
 
 .profLik <- function(object, param=1){
 
-    if(class(object)!="metaLik")
+    if(!inherits(object, "metaLik"))
         stop("\ninternal function designed for 'metaLik' objects")
     y <- object$y
     N <- length(y)
